@@ -234,7 +234,7 @@ use Glib::Object::Subclass Gscan2pdf::Dialog::, signals => {
     ),
   ];
 
-our $VERSION = '1.5.2';
+our $VERSION = '1.5.5';
 
 my ( $d, $d_sane, $logger, $tooltips );
 my $tolerance             = 1;
@@ -783,7 +783,8 @@ sub _set_allow_batch_flatbed {
     }
     else {
         my $options = $self->get('available-scan-options');
-        if ( defined $options
+        if (    defined $options
+            and $options->by_name('source')
             and $options->by_name('source')->{val} =~ /flatbed/xsmi )
         {
             $self->{framen}->set_sensitive(FALSE);
@@ -799,7 +800,8 @@ sub _set_allow_batch_flatbed {
 sub _set_available_scan_options {
     my ( $self, $name, $newval ) = @_;
     $self->{$name} = $newval;
-    if ( not $self->get('allow-batch-flatbed')
+    if (    not $self->get('allow-batch-flatbed')
+        and $newval->by_name('source')
         and $newval->by_name('source')->{val} =~ /flatbed/xsmi )
     {
         if ( $self->get('num-pages') != 1 ) { $self->set( 'num-pages', 1 ) }
@@ -818,7 +820,8 @@ sub _set_num_pages {
     if (
            $newval == 1
         or $self->get('allow-batch-flatbed')
-        or ( defined $options
+        or (    defined $options
+            and $options->by_name('source')
             and $options->by_name('source')->{val} !~ /flatbed/xsmi )
       )
     {
@@ -1545,15 +1548,6 @@ sub set_profile {
                 $self->signal_handler_disconnect($signal);
                 $self->{setting_profile} = FALSE;
 
-                # Having set all backend options, set the frontend options
-                if ( defined $self->{profiles}{$name}{frontend} ) {
-                    for my $key ( keys %{ $self->{profiles}{$name}{frontend} } )
-                    {
-                        $self->set( $key,
-                            $self->{profiles}{$name}{frontend}{$key} );
-                    }
-                }
-
                 # set property before emitting signal to ensure callbacks
                 # receive correct value
                 $self->{profile} = $name;
@@ -1996,12 +1990,13 @@ sub update_graph {
 # Set options to profile referenced by hashref
 
 sub set_current_scan_options {
-    my ( $self, $options_arrayref ) = @_;
+    my ( $self, $profile ) = @_;
 
-    if ( not defined $options_arrayref ) { return }
+    if ( not defined $profile ) { return }
+    $self->{setting_current_scan_options} = TRUE;
 
     # First clone the profile, as otherwise it would be self-modifying
-    my $clone = dclone($options_arrayref);
+    my $clone = dclone($profile);
 
     # As scanimage and scanadf rename the geometry options,
     # we have to map them back to the original names
@@ -2082,9 +2077,18 @@ sub _set_option_profile {
         }
     }
     else {
+
+        # Having set all backend options, set the frontend options
+        if ( defined $profile->{frontend} ) {
+            for my $key ( keys %{ $profile->{frontend} } ) {
+                $self->set( $key, $profile->{frontend}{$key} );
+            }
+        }
+
         if ( not $self->{setting_profile} ) {
             $self->set( 'profile', undef );
         }
+        $self->{setting_current_scan_options} = FALSE;
         $self->signal_emit(
             'changed-current-scan-options',
             $self->get('current-scan-options')
