@@ -79,7 +79,7 @@ use Glib::Object::Subclass Gscan2pdf::Dialog::Scan::, signals => {
     ),
   ];
 
-our $VERSION = '1.5.2';
+our $VERSION = '1.5.5';
 
 my $SANE_NAME_PAGE_HEIGHT = SANE_NAME_PAGE_HEIGHT;
 my $SANE_NAME_PAGE_WIDTH  = SANE_NAME_PAGE_WIDTH;
@@ -344,7 +344,10 @@ sub _initialise_options {    ## no critic (ProhibitExcessComplexity)
                 $opt->{type} == SANE_TYPE_GROUP
               ? $d_sane->get( $opt->{title} )
               : $d->get('Scan Options');
-            $self->{notebook}->append_page( $vbox, $group );
+            my $scwin = Gtk2::ScrolledWindow->new;
+            $self->{notebook}->append_page( $scwin, $group );
+            $scwin->set_policy( 'automatic', 'automatic' );
+            $scwin->add_with_viewport($vbox);
             $self->{option_widgets}{ $opt->{title} } = $vbox;
             if ( $opt->{type} == SANE_TYPE_GROUP ) { next }
         }
@@ -624,17 +627,7 @@ sub set_option {
 
                 $self->signal_emit( 'finished-process', 'find_scan_options' );
 
-                # Unset the profile unless we are actively setting it
-                if ( not $self->{setting_profile} ) {
-                    $self->set( 'profile', undef );
-                    $self->signal_emit(
-                        'changed-current-scan-options',
-                        $self->get('current-scan-options')
-                    );
-                }
-
-                $self->signal_emit( 'changed-scan-option', $option->{name},
-                    $val );
+                $self->_set_option_flags_signals( $option->{name}, $val );
                 $self->signal_emit('reloaded-scan-options');
             }
         }
@@ -692,17 +685,7 @@ sub set_option {
                     $self->signal_emit( 'finished-process',
                         'find_scan_options' );
 
-                    # Unset the profile unless we are actively setting it
-                    if ( not $self->{setting_profile} ) {
-                        $self->set( 'profile', undef );
-                        $self->signal_emit(
-                            'changed-current-scan-options',
-                            $self->get('current-scan-options')
-                        );
-                    }
-
-                    $self->signal_emit( 'changed-scan-option', $option->{name},
-                        $val );
+                    $self->_set_option_flags_signals( $option->{name}, $val );
                     $self->signal_emit('reloaded-scan-options');
                 },
                 error_callback => sub {
@@ -716,18 +699,26 @@ sub set_option {
         }
     }
     else {
+        $self->_set_option_flags_signals( $option->{name}, $val );
+    }
+    return;
+}
 
-        # Unset the profile unless we are actively setting it
-        if ( not $self->{setting_profile} ) {
-            $self->set( 'profile', undef );
+sub _set_option_flags_signals {
+    my ( $self, $name, $val ) = @_;
+
+    # Unset the profile unless we are actively setting it
+    if ( not $self->{setting_profile} ) {
+        $self->set( 'profile', undef );
+        if ( not $self->{setting_current_scan_options} ) {
             $self->signal_emit(
                 'changed-current-scan-options',
                 $self->get('current-scan-options')
             );
         }
-
-        $self->signal_emit( 'changed-scan-option', $option->{name}, $val );
     }
+
+    $self->signal_emit( 'changed-scan-option', $name, $val );
     return;
 }
 
