@@ -22,9 +22,16 @@ use Glib::Object::Subclass Gscan2pdf::Dialog::Scan::, properties => [
         'Log::Log4perl::get_logger object',    # blurb
         [qw/readable writable/]                # flags
     ),
+    Glib::ParamSpec->boolean(
+        'cycle-sane-handle',                                             # name
+        'Cycle SANE handle after scan',                                  # nick
+        'In some scanners, this allows the ADF to eject the last page',  # blurb
+        FALSE,                     # default_value
+        [qw/readable writable/]    # flags
+    ),
 ];
 
-our $VERSION = '1.5.2';
+our $VERSION = '1.5.5';
 
 my $SANE_NAME_SCAN_TL_X   = SANE_NAME_SCAN_TL_X;
 my $SANE_NAME_SCAN_TL_Y   = SANE_NAME_SCAN_TL_Y;
@@ -199,7 +206,10 @@ sub _initialise_options {    ## no critic (ProhibitExcessComplexity)
                 $opt->{type} == SANE_TYPE_GROUP
               ? $d_sane->get( $opt->{title} )
               : $d->get('Scan Options');
-            $self->{notebook}->append_page( $vbox, $group );
+            my $scwin = Gtk2::ScrolledWindow->new;
+            $self->{notebook}->append_page( $scwin, $group );
+            $scwin->set_policy( 'automatic', 'automatic' );
+            $scwin->add_with_viewport($vbox);
             if ( $opt->{type} == SANE_TYPE_GROUP ) { next }
         }
 
@@ -381,10 +391,14 @@ sub set_option {
             if ( not $self->{setting_profile} ) {
                 $self->set( 'profile', undef );
 
-                $self->signal_emit(
-                    'changed-current-scan-options',
-                    $self->get('current-scan-options')
-                );
+                # Emit the changed-current-scan-options signal
+                # unless we are actively setting it
+                if ( not $self->{setting_current_scan_options} ) {
+                    $self->signal_emit(
+                        'changed-current-scan-options',
+                        $self->get('current-scan-options')
+                    );
+                }
             }
 
             $self->signal_emit( 'changed-scan-option', $option->{name}, $val );
@@ -433,6 +447,12 @@ sub scan {
         },
         finished_callback => sub {
             $self->signal_emit( 'finished-process', 'scan_pages' );
+
+            if ( $self->get('cycle-sane-handle') ) {
+                my $current = $self->get('current-scan-options');
+                $self->scan_options( $self->get('device') );
+                $self->set_current_scan_options($current);
+            }
         },
         new_page_callback => sub {
             my ( $status, $path, $n ) = @_;
